
## CATO-CLI - query.policy.appTenantRestriction.policy:
[Click here](https://api.catonetworks.com/documentation/#query-policy) for documentation on this operation.

### Usage for query.policy.appTenantRestriction.policy:

`catocli query policy appTenantRestriction policy -h`

`catocli query policy appTenantRestriction policy <json>`

`catocli query policy appTenantRestriction policy "$(cat < policy.json)"`

`catocli query policy appTenantRestriction policy '{"appTenantRestrictionPolicyInput": {"policyRevisionInput": {"id": {"id": "ID"}, "type": {"type": "enum(PolicyRevisionType)"}}}}'`

#### Operation Arguments for query.policy.appTenantRestriction.policy ####
`accountId` [ID] - (required) N/A 
`appTenantRestrictionPolicyInput` [AppTenantRestrictionPolicyInput] - (optional) N/A 
